@@ -38,15 +38,15 @@ compile.CPTgrain <-
     ugM   <- triangulateMAT(mdagM)
     .timing(" Time: triangulate:", control, t0); t0 <- proc.time()
     
-    rip   <- ripMAT(ugM, nLevels = nlev)
+    .rip   <- ripMAT( ugM )
     .timing(" Time: rip:", control, t0); t0 <- proc.time()
 
-    jt    <- .createJTreeGraph(rip)
+    jt    <- .createJTreeGraph(.rip)
     .timing(" Time: create junction tree:", control, t0); t0 <- proc.time()
     
 ### Insert potentials; ## Input: rip, universe, cptlist
-    pot.with.1   <- .defaultPotentialList(rip, object$universe)     
-    origCQpot    <- tempCQpot <- .insertCpt(object$cptlist, pot.with.1, rip, details)
+    pot.with.1   <- .createPotList( .rip, object$universe )     
+    origCQpot    <- tempCQpot <- .insertCpt(object$cptlist, pot.with.1, details)
     equilCQpot   <- .insertNA(pot.with.1)
     .timing(" Time: insert cpt into potentials:", control, t0)
 
@@ -54,7 +54,7 @@ compile.CPTgrain <-
     mdag  <- as(mdagM, "graphNEL")
        
 ### Collect results
-    ans      <- list(rip         = rip,
+    ans      <- list(rip         = .rip,
                      jt          = jt,
                      ug          = ug,
                      equilCQpot  = equilCQpot,
@@ -131,91 +131,5 @@ compile.POTgrain <-
   return(jt)
 }
 
-.insertNA <- function(list.of.tables){
-  lapply(list.of.tables,
-         function(xxx){
-           xxx[] <- NA
-           xxx})
-}
 
 
-
-
-##    cat("compile.cpt-grain\n")
-            
-## ### Moralize DAG
-##     ## Input: dag
-##     t0   <- proc.time()
-##     mdag <- moralize(object$dag)
-##     if (!is.null(control$timing) && control$timing)
-##       cat("Time: moralize:", proc.time()-t0,"\n")
-        
-## ### Add edges between variables in 'root' to the moralized graph    
-##     ## Input: mdag
-##     if (!is.null(root) && length(root)>1){
-##       rootEdges <- combn(root,2)
-##       for (jj in 1:ncol(rootEdges)){
-##         if (!isAdjacent(mdag, rootEdges[1,jj], rootEdges[2,jj]))
-##           mdag <- addEdge(rootEdges[1,jj], rootEdges[2,jj], mdag)
-##       }
-##     }  
-    
-## ### Triangulate graph and create rooted junction tree
-##     ## Input: mdag, nlev
-##     t0    <- proc.time()
-##     vn    <- nodes(mdag)
-##     nlev  <- object$universe$nlev[vn]
-##     ug    <- triangulate(mdag, method=method, nLevels=nlev)
-##     rip   <- rip(ug, nLevels = nlev)
-##     jt    <- .createJTreeGraph(rip)
-##     if (!is.null(control$timing) && control$timing)
-##       cat("Time: triangulate:", proc.time()-t0,"\n")
-
-### Sparse version of it all
-##     mdagM <- moralizeMAT(object$dagM)
-##     if (!is.null(root) && length(root)>1){      
-##       vn <- object$universe$nodes
-##       dn <- dimnames(mdagM)    
-##       ft <- names2pairs(match(root, vn),sort=FALSE, result="matrix")
-##       ft <- rbind(ft,ft[,2:1,drop=FALSE])      
-##       mdagM <- sp_setXtf1(mdagM, ft)
-##       dimnames(mdagM) <- dn
-##     }
-
-
-    ##rr <<-rip
-
-    
-
-
-
-
-### Do we need elimination order???
-    ##    t0 <- proc.time()
-    ##     elorder <- .eliminationOrder(object$dag)  
-    ##     if (!is.null(control$timing) && control$timing)
-    ##       cat("Time: elimination order:", proc.time()-t0,"\n")
-    ##elorder <- NULL
-
-
-##     dg <<- object$dag
-##     md <<- mdag
-
-##     mdagM <- moralizeMAT(object$dagM)
-##     mdm <<- mdagM
-##     re  <<- rootEdges
-
-### Sparse version of it all
-##     mdagM <- moralizeMAT(object$dagM)
-##     if (!is.null(root) && length(root)>1){      
-##       vn <- object$universe$nodes
-##       dn <- dimnames(mdagM)    
-##       ft <- names2pairs(match(root, vn),sort=FALSE, result="matrix")
-##       ft <- rbind(ft,ft[,2:1,drop=FALSE])      
-##       mdagM <- sp_setXtf1(mdagM, ft)
-##       dimnames(mdagM) <- dn
-##     }
-##     ugM   <- triangulateMAT(mdagM, nlevels=nlev)
-##     ripM  <- ripMAT(ugM, nLevels = nlev)
-    ## After this point all we really need is rip, cptlist
-
